@@ -150,10 +150,6 @@ class AsStringVisitor:
             return f"{target}: {annotation}"
         return f"{target}: {annotation} = {node.value.accept(self)}"
 
-    def visit_repr(self, node):
-        """return an astroid.Repr node as string"""
-        return "`%s`" % node.value.accept(self)
-
     def visit_binop(self, node):
         """return an astroid.BinOp node as string"""
         left = self._precedence_parens(node, node.left)
@@ -284,32 +280,10 @@ class AsStringVisitor:
             excs = "except"
         return f"{excs}:\n{self._stmt_list(node.body)}"
 
-    def visit_ellipsis(self, node):
-        """return an astroid.Ellipsis node as string"""
-        return "..."
-
     def visit_empty(self, node):
         """return an Empty node as string"""
         return ""
 
-    def visit_exec(self, node):
-        """return an astroid.Exec node as string"""
-        if node.locals:
-            return "exec {} in {}, {}".format(
-                node.expr.accept(self),
-                node.locals.accept(self),
-                node.globals.accept(self),
-            )
-        if node.globals:
-            return "exec {} in {}".format(
-                node.expr.accept(self), node.globals.accept(self)
-            )
-        return "exec %s" % node.expr.accept(self)
-
-    def visit_extslice(self, node):
-        """return an astroid.ExtSlice node as string"""
-        return ", ".join(dim.accept(self) for dim in node.dims)
-
     def visit_for(self, node):
         """return an astroid.For node as string"""
         fors = "for {} in {}:\n{}".format(
@@ -473,15 +447,6 @@ class AsStringVisitor:
         """return an astroid.Pass node as string"""
         return "pass"
 
-    def visit_print(self, node):
-        """return an astroid.Print node as string"""
-        nodes = ", ".join(n.accept(self) for n in node.values)
-        if not node.nl:
-            nodes = "%s," % nodes
-        if node.dest:
-            return f"print >> {node.dest.accept(self)}, {nodes}"
-        return "print %s" % nodes
-
     def visit_raise(self, node):
         """return an astroid.Raise node as string"""
         if node.exc:
@@ -503,10 +468,6 @@ class AsStringVisitor:
 
         return "return"
 
-    def visit_index(self, node):
-        """return an astroid.Index node as string"""
-        return node.value.accept(self)
-
     def visit_set(self, node):
         """return an astroid.Set node as string"""
         return "{%s}" % ", ".join(child.accept(self) for child in node.elts)
