@@ -7,13 +7,16 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
 
-
-import astroid
-from astroid import exceptions
+from astroid.bases import BoundMethod
+from astroid.brain.helpers import register_module_extender
+from astroid.builder import parse
+from astroid.exceptions import InferenceError
+from astroid.manager import AstroidManager
+from astroid.scoped_nodes import FunctionDef
 
 
 def _multiprocessing_transform():
-    module = astroid.parse(
+    module = parse(
         """
     from multiprocessing.managers import SyncManager
     def Manager():
@@ -23,7 +26,7 @@ def _multiprocessing_transform():
     # Multiprocessing uses a getattr lookup inside contexts,
     # in order to get the attributes they need. Since it's extremely
     # dynamic, we use this approach to fake it.
-    node = astroid.parse(
+    node = parse(
         """
     from multiprocessing.context import DefaultContext, BaseContext
     default = DefaultContext()
@@ -33,7 +36,7 @@ def _multiprocessing_transform():
     try:
         context = next(node["default"].infer())
         base = next(node["base"].infer())
-    except exceptions.InferenceError:
+    except InferenceError:
         return module
 
     for node in (context, base):
@@ -42,16 +45,16 @@ def _multiprocessing_transform():
                 continue
 
             value = value[0]
-            if isinstance(value, astroid.FunctionDef):
+            if isinstance(value, FunctionDef):
                 # We need to rebound this, since otherwise
                 # it will have an extra argument (self).
-                value = astroid.BoundMethod(value, node)
+                value = BoundMethod(value, node)
             module[key] = value
     return module
 
 
 def _multiprocessing_managers_transform():
-    return astroid.parse(
+    return parse(
         """
     import array
     import threading
@@ -100,9 +103,9 @@ def _multiprocessing_managers_transform():
     )
 
 
-astroid.register_module_extender(
-    astroid.MANAGER, "multiprocessing.managers", _multiprocessing_managers_transform
+register_module_extender(
+    AstroidManager(), "multiprocessing.managers", _multiprocessing_managers_transform
 )
-astroid.register_module_extender(
-    astroid.MANAGER, "multiprocessing", _multiprocessing_transform
+register_module_extender(
+    AstroidManager(), "multiprocessing", _multiprocessing_transform
 )
