@@ -28,19 +28,15 @@ import functools
 import keyword
 from textwrap import dedent
 
-from astroid import (
-    MANAGER,
+from astroid import arguments, inference_tip, nodes, util
+from astroid.builder import AstroidBuilder, extract_node
+from astroid.exceptions import (
     AstroidTypeError,
     AstroidValueError,
     InferenceError,
     UseInferenceDefault,
-    arguments,
-    exceptions,
-    inference_tip,
-    nodes,
-    util,
 )
-from astroid.builder import AstroidBuilder, extract_node
+from astroid.manager import AstroidManager
 
 TYPING_NAMEDTUPLE_BASENAMES = {"NamedTuple", "typing.NamedTuple"}
 ENUM_BASE_NAMES = {
@@ -131,7 +127,7 @@ def infer_func_form(node, base_type, context=None, enum=False):
                     raise AttributeError from exc
                 if not attributes:
                     raise AttributeError from exc
-    except (AttributeError, exceptions.InferenceError) as exc:
+    except (AttributeError, InferenceError) as exc:
         raise UseInferenceDefault from exc
 
     if not enum:
@@ -210,7 +206,7 @@ def infer_named_tuple(node, context=None):
         field_def.format(name=name, index=index)
         for index, name in enumerate(attributes)
     )
-    fake = AstroidBuilder(MANAGER).string_build(
+    fake = AstroidBuilder(AstroidManager()).string_build(
         """
 class %(name)s(tuple):
     __slots__ = ()
@@ -362,6 +358,7 @@ def infer_enum_class(node):
             # Skip if the class is directly from enum module.
             break
         dunder_members = {}
+        target_names = set()
         for local, values in node.locals.items():
             if any(not isinstance(value, nodes.AssignName) for value in values):
                 continue
@@ -391,6 +388,7 @@ def infer_enum_class(node):
             for target in targets:
                 if isinstance(target, nodes.Starred):
                     continue
+                target_names.add(target.name)
                 # Replace all the assignments with our mocked class.
                 classdef = dedent(
                     """
@@ -414,7 +412,9 @@ def infer_enum_class(node):
                     # should result in some nice symbolic execution
                     classdef += INT_FLAG_ADDITION_METHODS.format(name=target.name)
 
-                fake = AstroidBuilder(MANAGER).string_build(classdef)[target.name]
+                fake = AstroidBuilder(AstroidManager()).string_build(classdef)[
+                    target.name
+                ]
                 fake.parent = target.parent
                 for method in node.mymethods():
                     fake.locals[method.name] = [method]
@@ -429,6 +429,29 @@ def infer_enum_class(node):
             ]
         )
         node.locals["__members__"] = [members]
+        # The enum.Enum class itself defines two @DynamicClassAttribute data-descriptors
+        # "name" and "value" (which we override in the mocked class for each enum member
+        # above). When dealing with inference of an arbitrary instance of the enum
+        # class, e.g. in a method defined in the class body like:
+        #     class SomeEnum(enum.Enum):
+        #         def method(self):
+        #             self.name  # <- here
+        # In the absence of an enum member called "name" or "value", these attributes
+        # should resolve to the descriptor on that particular instance, i.e. enum member.
+        # For "value", we have no idea what that should be, but for "name", we at least
+        # know that it should be a string, so infer that as a guess.
+        if "name" not in target_names:
+            code = dedent(
+                """
+            @property
+            def name(self):
+                return ''
+            """
+            )
+            name_dynamicclassattr = AstroidBuilder(AstroidManager()).string_build(code)[
+                "name"
+            ]
+            node.locals["name"] = [name_dynamicclassattr]
         break
     return node
 
@@ -513,26 +536,28 @@ def infer_typing_namedtuple(node, context=None):
     return infer_named_tuple(node, context)
 
 
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.Call, inference_tip(infer_named_tuple), _looks_like_namedtuple
 )
-MANAGER.register_transform(nodes.Call, inference_tip(infer_enum), _looks_like_enum)
-MANAGER.register_transform(
+AstroidManager().register_transform(
+    nodes.Call, inference_tip(infer_enum), _looks_like_enum
+)
+AstroidManager().register_transform(
     nodes.ClassDef,
     infer_enum_class,
     predicate=lambda cls: any(
         basename for basename in cls.basenames if basename in ENUM_BASE_NAMES
     ),
 )
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.ClassDef, inference_tip(infer_typing_namedtuple_class), _has_namedtuple_base
 )
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.FunctionDef,
     inference_tip(infer_typing_namedtuple_function),
     lambda node: node.name == "NamedTuple"
     and getattr(node.root(), "name", None) == "typing",
 )
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.Call, inference_tip(infer_typing_namedtuple), _looks_like_typing_namedtuple
 )
